Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1221)

Unified Diff: base/trace_event/trace_log.h

Issue 1424703003: Kills TraceTicks, which was functionally the same as TimeTicks (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed win compile error. Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/trace_event/trace_event_unittest.cc ('k') | base/trace_event/trace_log.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/trace_log.h
diff --git a/base/trace_event/trace_log.h b/base/trace_event/trace_log.h
index a68a3805b7895ef0d226927004b1ca5afee5886f..eb52733b35316180f2d2b7c13bd6921cf9e535ce 100644
--- a/base/trace_event/trace_log.h
+++ b/base/trace_event/trace_log.h
@@ -133,7 +133,7 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
// For TRACE_EVENT_PHASE_COMPLETE events, the client will still receive pairs
// of TRACE_EVENT_PHASE_BEGIN and TRACE_EVENT_PHASE_END events to keep the
// interface simple.
- typedef void (*EventCallback)(TraceTicks timestamp,
+ typedef void (*EventCallback)(TimeTicks timestamp,
char phase,
const unsigned char* category_group_enabled,
const char* name,
@@ -221,7 +221,7 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
unsigned long long id,
unsigned long long context_id,
int thread_id,
- const TraceTicks& timestamp,
+ const TimeTicks& timestamp,
int num_args,
const char** arg_names,
const unsigned char* arg_types,
@@ -236,7 +236,7 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
unsigned long long context_id,
unsigned long long bind_id,
int thread_id,
- const TraceTicks& timestamp,
+ const TimeTicks& timestamp,
int num_args,
const char** arg_names,
const unsigned char* arg_types,
@@ -301,7 +301,7 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
// sort index, ascending, then by their name, and then tid.
void SetThreadSortIndex(PlatformThreadId thread_id, int sort_index);
// Allow setting an offset between the current TraceTicks time and the time
// that should be reported.
void SetTimeOffset(TimeDelta offset);
@@ -374,7 +374,7 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
TraceBuffer* CreateTraceBuffer();
std::string EventToConsoleMessage(unsigned char phase,
- const TraceTicks& timestamp,
+ const TimeTicks& timestamp,
TraceEvent* trace_event);
TraceEvent* AddEventToThreadSharedChunkWhileLocked(TraceEventHandle* handle,
@@ -408,8 +408,8 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
}
void UseNextTraceBuffer();
- TraceTicks OffsetNow() const { return OffsetTimestamp(TraceTicks::Now()); }
- TraceTicks OffsetTimestamp(const TraceTicks& timestamp) const {
+ TimeTicks OffsetNow() const { return OffsetTimestamp(TimeTicks::Now()); }
+ TimeTicks OffsetTimestamp(const TimeTicks& timestamp) const {
return timestamp - time_offset_;
}
@@ -444,10 +444,10 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
base::hash_map<int, std::string> thread_names_;
// The following two maps are used only when ECHO_TO_CONSOLE.
- base::hash_map<int, std::stack<TraceTicks>> thread_event_start_times_;
+ base::hash_map<int, std::stack<TimeTicks>> thread_event_start_times_;
base::hash_map<std::string, int> thread_colors_;
- TraceTicks buffer_limit_reached_timestamp_;
+ TimeTicks buffer_limit_reached_timestamp_;
// XORed with TraceID to make it unlikely to collide with other processes.
unsigned long long process_id_hash_;
« no previous file with comments | « base/trace_event/trace_event_unittest.cc ('k') | base/trace_event/trace_log.cc » ('j') | no next file with comments »
@@ -301,7 +301,7 @@ class BASE_EXPORT TraceLog : public MemoryDumpProvider {
// sort index, ascending, then by their name, and then tid.
void SetThreadSortIndex(PlatformThreadId thread_id, int sort_index);
- // Allow setting an offset between the current TraceTicks time and the time
+ // Allow setting an offset between the current TimeTicks time and the time
// that should be reported.
void SetTimeOffset(TimeDelta offset);

Powered by Google App Engine
This is Rietveld 408576698